@@ -62,3 +62,10 @@ function wait_for_file_content {
         let COUNTER=COUNTER+1
     done
 }
+
+function expose_tcp() {
+    apisock=$1 hostport=$2 guestport=$3
+    json="{\"execute\": \"add_hostfwd\", \"arguments\": {\"proto\": \"tcp\", \"host_addr\": \"0.0.0.0\", \"host_port\": $hostport, \"guest_addr\": \"10.0.2.100\", \"guest_port\": $guestport}}"
+    echo -n $json | ncat -U $apisock
+    echo -n "{\"execute\": \"list_hostfwd\"}" | ncat -U $apisock
+}
